==> thux.organization-2.0.5.tar.gz: thux.organization-2.0.5/thux/organization/managers.py <==
# -*- coding: utf-8 -*-

from django.db import models
from django.db.models import Q


# Organization Managers
class OwnerOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='com', status=1)


class CustomerOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='cus', status=1)


class SupplierOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='sup', status=1)


class VectorOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='vec', status=1)


# Email Organization managers
class OwnerOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com', status=1)


class CustomerOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus', status=1)


class SupplierOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup', status=1)


class VectorOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec', status=1)


# Phone Organization managers
class OwnerOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com', status=1)


class CustomerOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus', status=1)


class SupplierOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup', status=1)


class VectorOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec', status=1)


# Social Page Organization
class OwnerOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com', status=1)


class CustomerOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus', status=1)


class SupplierOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup', status=1)


class VectorOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec', status=1)


# Contact managers
class ContactManager(models.Manager):
    def get_queryset(self):
        return super(ContactManager, self).get_queryset()


class OwnerContactManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com', status=1)


class CustomerContactManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus', status=1)


class SupplierContactManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup', status=1)


class WorkerContactManager(models.Manager):
    def get_queryset(self):
        qs = super(WorkerContactManager, self).get_queryset()
        return qs.filter(is_worker=True, status=1)


class VectorContactManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec', status=1)


# Email Contact managers
class OwnerContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='com', status=1)


class CustomerContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='cus', status=1)


class SupplierContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='sup', status=1)


class WorkerContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(WorkerContactEmailManager, self).get_queryset()
        return qs.filter(contact__is_worker=True, status=1)


class VectorContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='vec', status=1)


# Phone Contact managers
class OwnerContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='com', status=1)


class CustomerContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='cus', status=1)


class SupplierContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='sup', status=1)


class WorkerContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(WorkerContactPhoneManager, self).get_queryset()
        return qs.filter(contact__is_worker=True, status=1)


class VectorContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='vec', status=1)

==> thux.organization-2.0.6.tar.gz: thux.organization-2.0.6/thux/organization/managers.py <==
# -*- coding: utf-8 -*-

from django.db import models
from django.db.models import Q


# Organization Managers
class OwnerOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='com')


class CustomerOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='cus')


class SupplierOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='sup')


class VectorOrganizationManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationManager, self).get_queryset()
        return qs.filter(organization_type__category='vec')


# Email Organization managers
class OwnerOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com')


class CustomerOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus')


class SupplierOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup')


class VectorOrganizationEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationEmailManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec')


# Phone Organization managers
class OwnerOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com')


class CustomerOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus')


class SupplierOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup')


class VectorOrganizationPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationPhoneManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec')


# Social Page Organization
class OwnerOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com')


class CustomerOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus')


class SupplierOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup')


class VectorOrganizationSocialPageManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorOrganizationSocialPageManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec')


# Contact managers
class ContactManager(models.Manager):
    def get_queryset(self):
        return super(ContactManager, self).get_queryset()


class OwnerContactManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='com')


class CustomerContactManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='cus')


class SupplierContactManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='sup')


class WorkerContactManager(models.Manager):
    def get_queryset(self):
        qs = super(WorkerContactManager, self).get_queryset()
        return qs.filter(is_worker=True)


class VectorContactManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorContactManager, self).get_queryset()
        return qs.filter(organization__organization_type__category='vec')


# Email Contact managers
class OwnerContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='com')


class CustomerContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='cus')


class SupplierContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='sup')


class WorkerContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(WorkerContactEmailManager, self).get_queryset()
        return qs.filter(contact__is_worker=True)


class VectorContactEmailManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorContactEmailManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='vec')


# Phone Contact managers
class OwnerContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(OwnerContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='com')


class CustomerContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(CustomerContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='cus')


class SupplierContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(SupplierContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='sup')


class WorkerContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(WorkerContactPhoneManager, self).get_queryset()
        return qs.filter(contact__is_worker=True)


class VectorContactPhoneManager(models.Manager):
    def get_queryset(self):
        qs = super(VectorContactPhoneManager, self).get_queryset()
        return qs.filter(contact__organization__organization_type__category='vec')
